==> eam-wshub-proxyclient-11.5-10-sources.jar: net/datastream/schemas/mp_entities/worksafetydefault_001/WorkSafetyDefault.java <==

package net.datastream.schemas.mp_entities.worksafetydefault_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.STATUS_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DELETEPENDING"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RBSIGNATURETYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkSafetyDefault_001}SafetyReviewDetail" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RSTATUS" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="work_status_can_update" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="has_department_security" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="jtauth_can_update" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="true" />
 *       &lt;attribute name="is_mec_workorder" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="wo_has_multiequip" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "deletepending",
    "entity",
    "rbsignaturetype",
    "safetyReviewDetail",
    "rstatus"
})
@XmlRootElement(name = "WorkSafetyDefault")
public class WorkSafetyDefault {

    @XmlElement(name = "DELETEPENDING", namespace = "http://schemas.datastream.net/MP_fields", required = true, defaultValue = "false")
    protected String deletepending;
    @XmlElement(name = "ENTITY", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String entity;
    @XmlElement(name = "RBSIGNATURETYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String rbsignaturetype;
    @XmlElement(name = "SafetyReviewDetail")
    protected SafetyReviewDetail safetyReviewDetail;
    @XmlElement(name = "RSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type rstatus;
    @XmlAttribute(name = "work_status_can_update")
    protected String work_Status_Can_Update;
    @XmlAttribute(name = "has_department_security")
    protected String has_Department_Security;
    @XmlAttribute(name = "jtauth_can_update")
    protected String jtauth_Can_Update;
    @XmlAttribute(name = "is_mec_workorder")
    protected String is_Mec_Workorder;
    @XmlAttribute(name = "wo_has_multiequip")
    protected String wo_Has_Multiequip;

    /**
     * Obtient la valeur de la propriété deletepending.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDELETEPENDING() {
        return deletepending;
    }

    /**
     * Définit la valeur de la propriété deletepending.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDELETEPENDING(String value) {
        this.deletepending = value;
    }

    /**
     * Obtient la valeur de la propriété entity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITY() {
        return entity;
    }

    /**
     * Définit la valeur de la propriété entity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITY(String value) {
        this.entity = value;
    }

    /**
     * Obtient la valeur de la propriété rbsignaturetype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRBSIGNATURETYPE() {
        return rbsignaturetype;
    }

    /**
     * Définit la valeur de la propriété rbsignaturetype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRBSIGNATURETYPE(String value) {
        this.rbsignaturetype = value;
    }

    /**
     * Obtient la valeur de la propriété safetyReviewDetail.
     * 
     * @return
     *     possible object is
     *     {@link SafetyReviewDetail }
     *     
     */
    public SafetyReviewDetail getSafetyReviewDetail() {
        return safetyReviewDetail;
    }

    /**
     * Définit la valeur de la propriété safetyReviewDetail.
     * 
     * @param value
     *     allowed object is
     *     {@link SafetyReviewDetail }
     *     
     */
    public void setSafetyReviewDetail(SafetyReviewDetail value) {
        this.safetyReviewDetail = value;
    }

    /**
     * Obtient la valeur de la propriété rstatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getRSTATUS() {
        return rstatus;
    }

    /**
     * Définit la valeur de la propriété rstatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setRSTATUS(STATUS_Type value) {
        this.rstatus = value;
    }

    /**
     * Obtient la valeur de la propriété work_Status_Can_Update.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWork_Status_Can_Update() {
        if (work_Status_Can_Update == null) {
            return "false";
        } else {
            return work_Status_Can_Update;
        }
    }

    /**
     * Définit la valeur de la propriété work_Status_Can_Update.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWork_Status_Can_Update(String value) {
        this.work_Status_Can_Update = value;
    }

    /**
     * Obtient la valeur de la propriété has_Department_Security.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHas_Department_Security() {
        if (has_Department_Security == null) {
            return "false";
        } else {
            return has_Department_Security;
        }
    }

    /**
     * Définit la valeur de la propriété has_Department_Security.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHas_Department_Security(String value) {
        this.has_Department_Security = value;
    }

    /**
     * Obtient la valeur de la propriété jtauth_Can_Update.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getJtauth_Can_Update() {
        if (jtauth_Can_Update == null) {
            return "true";
        } else {
            return jtauth_Can_Update;
        }
    }

    /**
     * Définit la valeur de la propriété jtauth_Can_Update.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setJtauth_Can_Update(String value) {
        this.jtauth_Can_Update = value;
    }

    /**
     * Obtient la valeur de la propriété is_Mec_Workorder.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIs_Mec_Workorder() {
        if (is_Mec_Workorder == null) {
            return "false";
        } else {
            return is_Mec_Workorder;
        }
    }

    /**
     * Définit la valeur de la propriété is_Mec_Workorder.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIs_Mec_Workorder(String value) {
        this.is_Mec_Workorder = value;
    }

    /**
     * Obtient la valeur de la propriété wo_Has_Multiequip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWo_Has_Multiequip() {
        if (wo_Has_Multiequip == null) {
            return "false";
        } else {
            return wo_Has_Multiequip;
        }
    }

    /**
     * Définit la valeur de la propriété wo_Has_Multiequip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWo_Has_Multiequip(String value) {
        this.wo_Has_Multiequip = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_entities/worksafetydefault_001/WorkSafetyDefault.java <==

package net.datastream.schemas.mp_entities.worksafetydefault_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.STATUS_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DELETEPENDING"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RBSIGNATURETYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WorkSafetyDefault_001}SafetyReviewDetail" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RSTATUS" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="work_status_can_update" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="has_department_security" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="jtauth_can_update" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="true" />
 *       &lt;attribute name="is_mec_workorder" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="wo_has_multiequip" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "deletepending",
    "entity",
    "rbsignaturetype",
    "safetyReviewDetail",
    "rstatus"
})
@XmlRootElement(name = "WorkSafetyDefault")
public class WorkSafetyDefault {

    @XmlElement(name = "DELETEPENDING", namespace = "http://schemas.datastream.net/MP_fields", required = true, defaultValue = "false")
    protected String deletepending;
    @XmlElement(name = "ENTITY", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String entity;
    @XmlElement(name = "RBSIGNATURETYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String rbsignaturetype;
    @XmlElement(name = "SafetyReviewDetail")
    protected SafetyReviewDetail safetyReviewDetail;
    @XmlElement(name = "RSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type rstatus;
    @XmlAttribute(name = "work_status_can_update")
    protected String work_Status_Can_Update;
    @XmlAttribute(name = "has_department_security")
    protected String has_Department_Security;
    @XmlAttribute(name = "jtauth_can_update")
    protected String jtauth_Can_Update;
    @XmlAttribute(name = "is_mec_workorder")
    protected String is_Mec_Workorder;
    @XmlAttribute(name = "wo_has_multiequip")
    protected String wo_Has_Multiequip;

    /**
     * Gets the value of the deletepending property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDELETEPENDING() {
        return deletepending;
    }

    /**
     * Sets the value of the deletepending property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDELETEPENDING(String value) {
        this.deletepending = value;
    }

    /**
     * Gets the value of the entity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITY() {
        return entity;
    }

    /**
     * Sets the value of the entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITY(String value) {
        this.entity = value;
    }

    /**
     * Gets the value of the rbsignaturetype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRBSIGNATURETYPE() {
        return rbsignaturetype;
    }

    /**
     * Sets the value of the rbsignaturetype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRBSIGNATURETYPE(String value) {
        this.rbsignaturetype = value;
    }

    /**
     * Gets the value of the safetyReviewDetail property.
     * 
     * @return
     *     possible object is
     *     {@link SafetyReviewDetail }
     *     
     */
    public SafetyReviewDetail getSafetyReviewDetail() {
        return safetyReviewDetail;
    }

    /**
     * Sets the value of the safetyReviewDetail property.
     * 
     * @param value
     *     allowed object is
     *     {@link SafetyReviewDetail }
     *     
     */
    public void setSafetyReviewDetail(SafetyReviewDetail value) {
        this.safetyReviewDetail = value;
    }

    /**
     * Gets the value of the rstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getRSTATUS() {
        return rstatus;
    }

    /**
     * Sets the value of the rstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setRSTATUS(STATUS_Type value) {
        this.rstatus = value;
    }

    /**
     * Gets the value of the work_Status_Can_Update property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWork_Status_Can_Update() {
        if (work_Status_Can_Update == null) {
            return "false";
        } else {
            return work_Status_Can_Update;
        }
    }

    /**
     * Sets the value of the work_Status_Can_Update property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWork_Status_Can_Update(String value) {
        this.work_Status_Can_Update = value;
    }

    /**
     * Gets the value of the has_Department_Security property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getHas_Department_Security() {
        if (has_Department_Security == null) {
            return "false";
        } else {
            return has_Department_Security;
        }
    }

    /**
     * Sets the value of the has_Department_Security property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHas_Department_Security(String value) {
        this.has_Department_Security = value;
    }

    /**
     * Gets the value of the jtauth_Can_Update property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getJtauth_Can_Update() {
        if (jtauth_Can_Update == null) {
            return "true";
        } else {
            return jtauth_Can_Update;
        }
    }

    /**
     * Sets the value of the jtauth_Can_Update property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setJtauth_Can_Update(String value) {
        this.jtauth_Can_Update = value;
    }

    /**
     * Gets the value of the is_Mec_Workorder property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIs_Mec_Workorder() {
        if (is_Mec_Workorder == null) {
            return "false";
        } else {
            return is_Mec_Workorder;
        }
    }

    /**
     * Sets the value of the is_Mec_Workorder property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIs_Mec_Workorder(String value) {
        this.is_Mec_Workorder = value;
    }

    /**
     * Gets the value of the wo_Has_Multiequip property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWo_Has_Multiequip() {
        if (wo_Has_Multiequip == null) {
            return "false";
        } else {
            return wo_Has_Multiequip;
        }
    }

    /**
     * Sets the value of the wo_Has_Multiequip property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWo_Has_Multiequip(String value) {
        this.wo_Has_Multiequip = value;
    }

}
